@@ -1,3 +1,4 @@
+import copy
 import json
 import logging.config
 import os
@@ -142,10 +143,12 @@ def print_csv(df: pandas.DataFrame, output: Optional[str] = None, to_csv_kwargs:
 
     path_or_buf = sys.stdout if output is None else output
 
+    kwargs = copy.deepcopy(DEFAULT_CSV_FORMAT)
     if to_csv_kwargs is None:
-        df.to_csv(path_or_buf, **DEFAULT_CSV_FORMAT)
+        df.to_csv(path_or_buf, **kwargs)
     else:
-        df.to_csv(path_or_buf, **to_csv_kwargs)
+        kwargs.update(to_csv_kwargs)
+        df.to_csv(path_or_buf, **kwargs)
 
     if output is not None:
         logger.info(f"{output} に出力しました。")
@@ -337,11 +340,31 @@ def read_multiheader_csv(csv_file: str, header_row_count: int = 2, **kwargs) ->
         columns = df.columns.levels[level]
         rename_columns = {c: "" for c in columns if re.fullmatch(r"Unnamed: .*", c) is not None}
         df.rename(
-            columns=rename_columns, level=level, inplace=True,
+            columns=rename_columns,
+            level=level,
+            inplace=True,
         )
     return df
 
 
+def get_columns_with_priority(df: pandas.DataFrame, prior_columns: List[Any]) -> List[str]:
+    """
+    優先順位の高い列を先頭にした、列名リストを取得します。
+
+    Args:
+        df: 対象のpandas.DataFrame
+        prior_columns: 優先順位の高い列名リスト
+
+    Returns:
+        列名リスト
+    """
+    # 存在しない列名を取り除く
+    tmp_prior_columns = [c for c in prior_columns if c in df.columns]
+    remained_columns = list(df.columns.difference(tmp_prior_columns))
+    all_columns = tmp_prior_columns + remained_columns
+    return all_columns
+
+
 def _catch_exception(function: Callable[..., Any]) -> Callable[..., Any]:
     """
     Exceptionをキャッチしてログにstacktraceを出力する。
